Processor.App.processor_utils.PipeMetadata.__init__ — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.App.processor_utils.PipeMetadata.__init__

PipeMetadata.__init__(domain_record: ~Processor.App.processor_utils.DomainRecord, article_data: ~typing.Dict[~typing.Any, ~typing.Any] = <factory>, warc_header: ~typing.Dict[str, ~typing.Any] = <factory>, http_header: ~typing.Dict[str, ~typing.Any] = <factory>, encoding: str = 'latin-1', name: ~typing.Optional[str] = None) → None